#!/usr/bin/env python3

from string import ascii_letters, digits
from sys import stdin, stderr

# This is a modified version of a script originally by Ken Dwyer and is
# modified and distributed with permission
__author__ = 'Aditya Bhargava'
__license__ = 'FreeBSD'
__version__ = '1.0.0'
__email__ = 'aditya@cs.toronto.edu'


def errordie(msg):
    print(msg, file=stderr)
    exit(1)

map = {
    'ज़': ['z', 'eC'],
    'ड़': ['rX', 'eC'],
    'ऴ': ['lXH', 'eC'],
    'ङ': ['gN', 'eC'],
    'ऱ': ['rH', 'eC'],  # not sure
    'अ': ['eC'],
    'आ': ['a'],
    'ा': ['~', 'a'],
    'इ': ['iL'],
    'ि': ['~', 'iL'],
    'ई': ['i'],
    'ी': ['~', 'i'],
    'उ': ['uL'],
    'ु': ['~', 'uL'],
    'ऊ': ['u'],
    'ू': ['~', 'u'],
    'ऋ': ['riL'],
    'ृ': ['~', 'riL'],
    'ए': ['e'],
    'े': ['~', 'e'],
    'ऐ': ['aF'],  # usually ɛ in Hindi; using aF for English loanwords
    'ै': ['~', 'aF'],  # usually ɛ in Hindi; using aF for English loanwords
    'ओ': ['o'],
    'ो': ['~', 'o'],
    'औ': ['oL'],  # could also be au
    'ौ': ['~', 'oL'],  # could also be au
    'ं': ['*'],
    'ँ': ['*'],
    'क': ['k', 'eC'],
    'ख': ['kA', 'eC'],
    'ग': ['g', 'eC'],
    'घ': ['gA', 'eC'],
    'च': ['cV', 'eC'],
    'छ': ['cVA', 'eC'],
    'ज': ['jV', 'eC'],
    'झ': ['jVA', 'eC'],
    'ञ': ['nP', 'eC'],
    'ट': ['tX', 'eC'],
    'ठ': ['tXA', 'eC'],
    'ड': ['dX', 'eC'],
    'ढ': ['dXA', 'eC'],
    'ण': ['nX', 'eC'],
    'त': ['tD', 'eC'],
    'थ': ['tDA', 'eC'],
    'द': ['dD', 'eC'],
    'ध': ['dDA', 'eC'],
    'न': ['n', 'eC'],
    'प': ['p', 'eC'],
    'फ': ['f', 'eC'],  # should actually be pA but using f for English
    'ब': ['b', 'eC'],
    'भ': ['bA', 'eC'],
    'म': ['m', 'eC'],
    'य': ['y', 'eC'],
    'र': ['rH', 'eC'],
    'ल': ['l', 'eC'],
    'व': ['v', 'eC'],
    'श': ['sV', 'eC'],
    'ष': ['sV', 'eC'],
    'स': ['s', 'eC'],
    'ह': ['hL', 'eC'],
    '्': ['~'],
    'ॅ': ['~', 'aF'],  # c an be any of aF, e, eC, a, ɛ; aF is most common
    'ॉ': ['~', 'oL'],  # similar but oL isn't as clear a choice (alt. is a)
    '़': ['.'],
    '१': ['1'],
    '२': ['2'],
    '३': ['3'],
    '४': ['4'],
    '५': ['5'],
    '६': ['6'],
    '७': ['7'],
    '८': ['8'],
    '९': ['9'],
    '०': ['0'],
    'ऍ': ['aF'],  # can be many things (aF, e, eC, a, ɛ), aF is most common
    '‍': [''],
    'ॄ': ['~', 'ri'],
    'ः': ['h'],
    'ळ': ['lX', 'eC'],
    '॰': ['$'],
    ' ॑': ['\''],
    'ऑ': ['oL']}

do_not_convert = ascii_letters + digits + "_-' "
vowels = ['eC', 'a', 'iL', 'i', 'uL', 'u', 'e', 'aF', 'o', 'oL']


def nasalize(letter):
    if letter in vowels:
        return letter + 'N'


def convert(hindi):
    ipa = []
    for letter in hindi:
        if letter in do_not_convert:
            ipa.append(letter)
        else:
            try:
                ipa.extend(map[letter])
            except KeyError:
                errordie('hindi2aline: No conversion for %s in word %s' %
                         (letter, hindi))
    for i in range(len(ipa)):
        if ipa[i] == '.':
            if ipa[i - 2] == 'pA' or ipa[i - 2] == 'f':
                ipa[i] = '+'
                ipa[i - 2] = 'f'
            elif ipa[i - 2] == 'jV':
                ipa[i] = '+'
                ipa[i - 2] = 'z'
            elif ipa[i - 2] == 'dX':
                ipa[i] = '+'
                ipa[i - 2] = 'rX'
            elif ipa[i - 2] == 'dXA':
                ipa[i] = '+'
                ipa[i - 2] = 'rXA'
            elif ipa[i - 2] == 'k':
                ipa[i] = '+'
                ipa[i - 2] = 'kU'
            elif ipa[i - 2] == 'kA':
                ipa[i] = '+'
                ipa[i - 2] = 'x'
            elif ipa[i - 2] == 'g':
                ipa[i] = '+'
                ipa[i - 2] = 'gS'
        elif ipa[i] == '~':
            j = i - 1
            while ipa[j] in vowels + ['+']:
                ipa[j] = '~'
                j -= 1
        elif ipa[i] == '*':
            if len(ipa) == i + 1 or ipa[i + 1] == ' ':  # word-final
                ipa[i - 1] = nasalize(ipa[i - 1])
            elif ipa[i + 1] in ['k', 'kA', 'g', 'gA', 'hL']:
                ipa[i] = 'gN'
            elif ipa[i + 1] in ['cV', 'cVA', 'jV', 'jVA']:
                ipa[i] = 'nP'
            elif ipa[i + 1] in ['tX', 'tXA', 'dX', 'dXA']:
                ipa[i] = 'nX'
            elif ipa[i + 1] in ['tD', 'tDA', 'dD', 'dDA']:
                ipa[i] = 'n'
            elif ipa[i + 1] in ['p', 'pA', 'b', 'bA']:
                ipa[i] = 'm'
            else:
                ipa[i] = 'n'
    ipa = ''.join(c for c in ipa if c not in '~+*')
    if ipa.endswith('eC'):
        ipa = ipa[:-2]  # delete word-final schwas
    ipa = ipa.replace('eC ', ' ')  # more word-final schwas
    ipa = ipa.replace('$', '.')
    ipa = ipa.replace(' ', '')
    return ipa

for line in stdin.readlines():
    hindi = ''.join(ch for ch in line.strip().split('\t')[0] if ch != '+')
    print(convert(hindi))
